@@ -1,6 +1,7 @@
 package Path::Class::Dir;
-
-$VERSION = '0.21';
+BEGIN {
+  $Path::Class::Dir::VERSION = '0.22';
+}
 
 use strict;
 use Path::Class::File;
@@ -71,6 +72,8 @@ sub file {
   return $_[0]->file_class->new(@_);
 }
 
+sub basename { shift()->{dirs}[-1] }
+
 sub dir_list {
   my $self = shift;
   my $d = $self->{dirs};
@@ -258,6 +261,10 @@ __END__
 
 Path::Class::Dir - Objects representing directories
 
+=head1 VERSION
+
+version 0.22
+
 =head1 SYNOPSIS
 
   use Path::Class qw(dir);  # Export a short constructor
@@ -650,4 +657,4 @@ Ken Williams, kwilliams@cpan.org
 
 Path::Class, Path::Class::File, File::Spec
 
-=cut
+=cut
\ No newline at end of file
